@@ -1,7 +1,10 @@
 from .tgpt import TGPT
 from .imager import Imager
+from .utils import Optimizers
+from .utils import Conversation
+from .utils import AwesomePrompts
 
-__version__ = "0.0.8"
+__version__ = "0.1.2"
 __author__ = "Smartwa"
 __repo__ = "https://github.com/Simatwa/python-tgpt"
 
