@@ -10,6 +10,7 @@ import rich
 import getpass
 import json
 import re
+import platform
 from time import sleep
 from threading import Thread as thr
 from functools import wraps
@@ -21,6 +22,7 @@ from rich.live import Live
 from rich.prompt import Prompt
 from typing import Iterator
 from tgpt.utils import Optimizers
+from tgpt.utils import default_path
 
 getExc = lambda e: e.args[1] if len(e.args) > 1 else str(e)
 
@@ -166,7 +168,7 @@ class busy_bar:
 
 class Main(cmd.Cmd):
     intro = f"Welcome to AI Chat in terminal. Type 'help' or '?' for usage info \n Submit any bug at {tgpt.__repo__}/issues/new"
-    prompt = f"╭─[{getpass.getuser().capitalize()}@TGPT2](v{tgpt.__version__})\n╰─>"
+    prompt = f"╭─[{getpass.getuser().capitalize()}@TGPT](v{tgpt.__version__})\n╰─>"
 
     def __init__(
         self,
@@ -177,10 +179,12 @@ class Main(cmd.Cmd):
         model,
         brave_key,
         timeout,
-        conversation,
+        disable_conversation,
         filepath,
         update_file,
         intro,
+        history_offset,
+        awesome_prompt,
         proxy_path,
         quiet=False,
         *args,
@@ -192,20 +196,27 @@ class Main(cmd.Cmd):
                 proxies = json.load(fh)
         else:
             proxies = {}
-        self.bot = tgpt.TGPT(
-            conversation,
-            max_tokens,
-            temperature,
-            top_k,
-            top_p,
-            model,
-            brave_key,
-            timeout,
-            intro,
-            filepath,
-            update_file,
-            proxies,
-        )
+        try:
+            self.bot = tgpt.TGPT(
+                disable_conversation,
+                max_tokens,
+                temperature,
+                top_k,
+                top_p,
+                model,
+                brave_key,
+                timeout,
+                intro,
+                filepath,
+                update_file,
+                proxies,
+                history_offset,
+                awesome_prompt,
+            )
+        except Exception as e:
+            logging.error(getExc(e))
+            click.secho("Quitting", fg="red")
+            exit(1)
         self.prettify = True
         self.color = "cyan"
         self.code_theme = "monokai"
@@ -395,12 +406,12 @@ class Main(cmd.Cmd):
     def do_history(self, line):
         """Show current conversation history"""
         history = self.bot.conversation.chat_history
-        history = re.sub(
+        formatted_history = re.sub(
             "\nLLM :",
             "\n\n**LLM** :",
             re.sub("\nUser :", "\n\n**User** :", history),
         )
-        self.output_bond("Chat History", history, self.color)
+        self.output_bond("Chat History", formatted_history, self.color)
         if click.confirm("Do you wish to save this chat"):
             save_to = click.prompt(
                 "Enter path/file-name", default="llama-conversation.txt"
@@ -417,6 +428,17 @@ class Main(cmd.Cmd):
         )
         click.secho("Conversation reset successfully. New one created.", fg="cyan")
 
+    @busy_bar.run("while loading conversation")
+    def do_load(self, line):
+        """Load conversation history from file"""
+        history_file = click.prompt("Enter path to history path", default=line)
+        if not os.path.isfile(history_file):
+            click.secho(f"Path `{history_file}` does not exist!", fg="red")
+            return
+        with open(history_file) as fh:
+            self.bot.conversation.chat_history = fh.read()
+        click.secho("Conversation loaded successfully.", fg="cyan")
+
     @busy_bar.run()
     def default(self, line):
         """Chat with ChatGPT"""
@@ -544,16 +566,17 @@ def tgpt2_():
     "--prettify/--raw", help="Flag for prettifying markdowned response", default=True
 )
 @click.option(
-    "-C",
-    "--conversation",
+    "-dc",
+    "--disable-conversation",
     is_flag=True,
-    default=False,
-    help="Chat conversationally (Experimental)",
+    default=True,  # is_conversation = True
+    help="Disable chatting conversationally (Stable)",
 )
 @click.option(
     "-fp",
     "--filepath",
     type=click.Path(),
+    default=os.path.join(default_path, "chat-history.txt"),
     help="Path to chat history - new will be created incase doesn't exist",
 )
 @click.option(
@@ -566,6 +589,21 @@ def tgpt2_():
     "--intro",
     help="Conversation introductory prompt",
 )
+@click.option(
+    "-ho",
+    "--history-offset",
+    envvar="history_offset",
+    help="Limit conversation history to this number of last texts",
+    type=click.IntRange(100, 16000),
+    default=10250,
+)
+@click.option(
+    "-ap",
+    "--awesome-prompt",
+    default="0",
+    callback=lambda ctx, param, value: int(value) if str(value).isdigit() else value,
+    help="Awesome prompt key or index. Alt. to intro",
+)
 @click.option(
     "-pp",
     "--proxy-path",
@@ -593,10 +631,12 @@ def interactive(
     timeout,
     prompt,
     prettify,
-    conversation,
+    disable_conversation,
     filepath,
     update_file,
     intro,
+    history_offset,
+    awesome_prompt,
     proxy_path,
     quiet,
 ):
@@ -630,10 +670,12 @@ def interactive(
         model,
         brave_key,
         timeout,
-        conversation,
+        disable_conversation,
         filepath,
         update_file,
         intro,
+        history_offset,
+        awesome_prompt,
         proxy_path,
         quiet,
     )
@@ -733,16 +775,17 @@ def interactive(
     help="Optimize prompt for shell command generation",
 )
 @click.option(
-    "-C",
-    "--conversation",
+    "-dc",
+    "--disable-conversation",
     is_flag=True,
-    default=False,
-    help="Chat conversationally (Experimental)",
+    default=True,  # is_conversation = True
+    help="Disable chatting conversationally (Stable)",
 )
 @click.option(
     "-fp",
     "--filepath",
     type=click.Path(),
+    default=os.path.join(default_path, "chat-history.txt"),
     help="Path to chat history - new will be created incase doesn't exist",
 )
 @click.option(
@@ -755,6 +798,21 @@ def interactive(
     "--intro",
     help="Conversation introductory prompt",
 )
+@click.option(
+    "-ho",
+    "--history-offset",
+    envvar="history_offset",
+    help="Limit conversation history to this number of last texts",
+    type=click.IntRange(100, 16000),
+    default=10250,
+)
+@click.option(
+    "-ap",
+    "--awesome-prompt",
+    default="0",
+    callback=lambda ctx, param, value: int(value) if str(value).isdigit() else value,
+    help="Awesome prompt key or index. Alt. to intro",
+)
 @click.option(
     "-pp",
     "--proxy-path",
@@ -785,10 +843,12 @@ def generate(
     whole,
     code,
     shell,
-    conversation,
+    disable_conversation,
     filepath,
     update_file,
     intro,
+    history_offset,
+    awesome_prompt,
     proxy_path,
     quiet,
 ):
@@ -801,10 +861,12 @@ def generate(
         model,
         brave_key,
         timeout,
-        conversation,
+        disable_conversation,
         filepath,
         update_file,
         intro,
+        history_offset,
+        awesome_prompt,
         proxy_path,
         quiet,
     )
@@ -830,7 +892,7 @@ def generate(
             click.secho(
                 help_info
             )  # Let's try to mimic the click's missing argument help info
-            exit(1)
+            sys.exit(1)
         else:
             signal.alarm(0)  # Reset the alarm if input is read successfully
             # Just incase the previous timeout was not 0
@@ -846,12 +908,20 @@ def generate(
 
 def main():
     args = sys.argv
+    if "--version" in args:
+        # Lets show version here and exit
+        click.secho(f"tgpt v{tgpt.__version__}")
+        sys.exit(0)
     if (
         len(args) > 1
         and args[1] not in ["interactive", "generate"]
         and not "--help" in args
     ):
-        sys.argv.insert(1, "generate")  # Just a hack to make 'generate' default command
+        sys.argv.insert(1, "generate")  # Just a hack to make default command
+    elif (
+        len(args) == 1
+    ):  # and platform.system() == "Windows": What do you think about this?
+        sys.argv.insert(1, "interactive")
     tgpt2_()
 
 
