@@ -2,6 +2,7 @@ import requests
 import json
 from .utils import Optimizers
 from .utils import Conversation
+from .utils import AwesomePrompts
 
 session = requests.Session()
 
@@ -9,7 +10,7 @@ session = requests.Session()
 class TGPT:
     def __init__(
         self,
-        is_conversation: bool = False,
+        is_conversation: bool = True,
         max_tokens: int = 600,
         temperature: float = 0.2,
         top_k: int = -1,
@@ -21,11 +22,13 @@ class TGPT:
         filepath: str = None,
         update_file: bool = True,
         proxies: dict = {},
+        history_offset: int = 10250,
+        act: str = None,
     ):
         """Instantiate TGPT
 
         Args:
-            conversationally (str, optional): Flag for chatting conversationally. Defaults to False.
+            is_conversation (str, optional): Flag for chatting conversationally. Defaults to True.
             brave_key (str, optional): Brave API access key. Defaults to "qztbjzBqJueQZLFkwTTJrieu8Vw3789u".
             model (str, optional): Text generation model name. Defaults to "llama-2-13b-chat".
             max_tokens (int, optional): Maximum number of tokens to be generated upon completion. Defaults to 600.
@@ -36,6 +39,8 @@ class TGPT:
             intro (str, optional): Conversation introductory prompt. Defaults to `Conversation.intro`.
             filepath (str, optional): Path to file containing conversation history. Defaults to None.
             update_file (bool, optional): Add new prompts and responses to the file. Defaults to True.
+            history_offset (int, optional): Limit conversation history to this number of last texts. Defaults to 10250.
+            act (str|int, optional): Awesome prompt key or index. (Used as intro). Defaults to None.
         """
         self.is_conversation = is_conversation
         self.max_tokens_to_sample = max_tokens
@@ -59,8 +64,17 @@ class TGPT:
             if callable(getattr(Optimizers, method)) and not method.startswith("__")
         )
         session.headers.update(self.headers)
-        Conversation.intro = intro or Conversation.intro
-        self.conversation = Conversation(is_conversation, filepath, update_file)
+        Conversation.intro = (
+            AwesomePrompts().get_act(
+                act, raise_not_found=True, default=None, case_insensitive=True
+            )
+            if act
+            else intro or Conversation.intro
+        )
+        self.conversation = Conversation(
+            is_conversation, self.max_tokens_to_sample, filepath, update_file
+        )
+        self.conversation.history_offset = history_offset
         session.proxies = proxies
 
     def ask(
